import React, { useState, useRef, useEffect } from 'react';
import {
    ProForm,
    ProFormDigit,
    ProFormText,
    ProFormSelect,
    ProFormDateTimePicker
} from '@ant-design/pro-components';
import { FormattedMessage, useIntl } from '@umijs/max';
import { Form, Modal } from 'antd';
import moment from 'moment';
import Http from '@/utils/http';

const Edit = (props) => {
    const intl = useIntl();
    const [form] = Form.useForm();
    const { } = props;

    useEffect(() => {
        form.resetFields();
        form.setFieldsValue({
            ...props.values
        })
    }, [form, props])

    const handleCancel = () => {
        props.onCancel();
    };

    const handleOk = () => {
        form.submit();
    }

    const handleFinish = async (values) => {
        props.onSubmit({ ...values });
    }

    return (
        <>
            <Modal
                title="Edit"
                width={640}
                forceRender
                destroyOnClose
                open={props.open}
                onCancel={handleCancel}
                onOk={handleOk}
            >
                <ProForm
                    form={form}
                    submitter={false}
                    onFinish={handleFinish}
                    layout="horizontal"
                    grid={true}
                >
                    <ProFormDigit
                        name="id"
                        disabled
                        hidden={true}
                    />
                    <ProForm.Group>
                        <ProFormText
                            name="namespace"
                            label="名称空间"
                            colProps={{ md: 12, xl: 12 }}
                            placeholder="请输入"
                        />
                        <ProFormText
                            name="url"
                            label="接口地址"
                            colProps={{ md: 12, xl: 12 }}
                            placeholder="请输入"
                        />
                    </ProForm.Group>
                    <ProForm.Group>
                        <ProFormText
                            name="appkey"
                            label="平台密钥"
                            colProps={{ md: 12, xl: 12 }}
                            placeholder="请输入"
                        />
                        <ProFormText
                            name="timestamp"
                            label="时间戳"
                            colProps={{ md: 12, xl: 12 }}
                            placeholder="请输入"
                        />
                    </ProForm.Group>
                    <ProForm.Group>
                        <ProFormText
                            name="clientIp"
                            label="客户端IP"
                            colProps={{ md: 12, xl: 12 }}
                            placeholder="请输入"
                        />
                        <ProFormText
                            name="request"
                            label="请求内容"
                            colProps={{ md: 12, xl: 12 }}
                            placeholder="请输入"
                        />
                    </ProForm.Group>
                    <ProForm.Group>
                        <ProFormText
                            name="response"
                            label="响应内容"
                            colProps={{ md: 12, xl: 12 }}
                            placeholder="请输入"
                        />
                        <ProFormDigit
                            name="spendTime"
                            label="消耗时间"
                            colProps={{ md: 12, xl: 12 }}
                            fieldProps={{ precision: 0 }}
                            placeholder="请输入"
                        />
                    </ProForm.Group>
                    <ProForm.Group>
                        <ProFormText
                            name="err"
                            label="异常内容"
                            colProps={{ md: 12, xl: 12 }}
                            placeholder="请输入"
                        />
                        <ProFormSelect
                            name="result"
                            label="结果"
                            colProps={{ md: 12, xl: 12 }}
                            placeholder="请选择"
                            options={[
                                { label: '成功', value: 1 },
                                { label: '失败', value: 0 },
                            ]}
                        />
                    </ProForm.Group>
                    <ProForm.Group>
                        <ProFormSelect
                            name="userId"
                            label="用户"
                            colProps={{ md: 12, xl: 12 }}
                            fieldProps={{ precision: 0 }}
                            placeholder="请选择"
                            showSearch
                            debounceTime={300}
                            request={async ({ keyWords }) => {
                                const resp = await Http.doPostForm('api/user/query', { condition: keyWords });
                                return resp.data;
                            }}
                        />
                        <ProFormDateTimePicker
                            name="createTime"
                            label="添加时间"
                            colProps={{ md: 12, xl: 12 }}
                            placeholder="请选择"
                            transform={(value) => moment(value).toISOString()}
                        />
                    </ProForm.Group>

                </ProForm>
            </Modal>
        </>
    )
}

export default Edit;
